"use client";
import Image from "next/image";

import { Locale } from "@/i18n/routing";
import { fetchAbout } from "@/servers/actions/about-action";
import { useQuery } from "@tanstack/react-query";
import { useLocale } from "next-intl";

export default function Features() {  
  const locale = useLocale() as Locale;
  const isRTL = locale === "ar";
 // const { items } = await getFeaturesData();

  const { data: features } = useQuery({
    queryKey: ["about"],
    queryFn: () => fetchAbout(),
  });
  
  return (
    <section className="container mx-auto px-4 py-16 md:px-6 lg:px-24 lg:pb-28">
      <div className="grid grid-cols-1 gap-8 md:grid-cols-2 lg:grid-cols-3">
        {features?.data?.cards?.map((feature: any) => (
          <div
            key={feature?.id}
            className={`relative rounded-lg bg-white p-8 text-center border border-gray-300 ${
              isRTL ? "text-right" : "text-left"
            }`}
            style={{
              boxShadow: "0 72px 24px -55px rgba(4, 37, 51, 0.08)",
            }}
          >
            {features?.data?.cards?.indexOf(feature) === 1 && (
              <div
                className="absolute inset-0 rounded-lg"
                style={{
                  boxShadow: "inset 0 0 0 1px #2895C8",
                }}
              />
            )}
            <div className="mx-auto mb-6 flex h-16 w-16 justify-center rounded-full border-4 border-custom-border bg-custom-primary-accent p-2">
              <Image
                src={"/icons/swimming-pool.png"} // TODO: change to the correct url icon from the backend
                alt={feature?.title?.[`_${locale}`]}
                width={200}
                quality={100}
                height={200}
              />
            </div>
            <h3 className="mb-4 text-xl font-bold text-custom-dark">
              {locale === "ar" ? feature?.title_ar : feature?.title_en}
            </h3>
            <p className="text-custom-gray">{locale === "ar" ? feature?.content_ar : feature?.content_en}</p>
          </div>
        ))}
      </div>
    </section>
  );
}
